@@ -7,9 +7,9 @@ import jeepney
 import jeepney.io.blocking
 import pytest
 
+from dbus_objects import DBusObject, custom_dbus_signal, dbus_method, dbus_property, dbus_signal
 from dbus_objects.integration import DBusServerBase
 from dbus_objects.integration.jeepney import BlockingDBusServer
-from dbus_objects.object import DBusObject, dbus_method, dbus_property
 from dbus_objects.types import MultipleReturn
 
 
@@ -35,7 +35,7 @@ class ExampleObject(DBusObject):
 
     @dbus_method(multiple_returns=True)
     def multiple(self, msg: str) -> MultipleReturn[int, int]:
-        print(msg)  # pragma: no cover
+        return 1, 2  # pragma: no cover
 
     @dbus_property()
     def prop(self) -> str:
@@ -46,6 +46,32 @@ class ExampleObject(DBusObject):
         self._property = value
 
 
+class ExampleObjectWithSignal(DBusObject):
+    def __init__(self):
+        super().__init__(default_interface_root='com.example.object')
+
+    signal = dbus_signal(
+        value=int,
+        other_value=str,
+    )
+    signal2 = dbus_signal(float, int)
+    custom_signal = custom_dbus_signal(name='SpecialSignal')(int, int)
+    custom_signal2 = custom_dbus_signal(name='SpecialSignal2')(
+        name=str,
+        age=int,
+    )
+
+
+class DummyServer(DBusServerBase):
+    def __init__(self, bus: str, name: str):
+        super().__init__(bus, name)
+        self.emit_signal_callback = self.emit_signal
+        self.emitted_signal = None
+
+    def emit_signal(self, signal, path, body):
+        self.emitted_signal = (signal.name, path, body)
+
+
 @pytest.fixture(scope='session')
 def obj():
     return ExampleObject()
@@ -61,6 +87,26 @@ def obj_properties(obj):
     return obj.get_dbus_properties()
 
 
+@pytest.fixture()
+def signal_obj():
+    return ExampleObjectWithSignal()
+
+
+@pytest.fixture()
+def obj_signals(signal_obj):
+    return signal_obj.get_dbus_signals()
+
+
+@pytest.fixture()
+def signal_server(signal_obj):
+    server = DummyServer(
+        bus='SESSION',
+        name='io.github.ffy00.dbus-objects.tests'
+    )
+    server.register_object('/io/github/ffy00/dbus_objects/example', signal_obj)
+    yield server
+
+
 @pytest.fixture()
 def base_server(obj):
     server = DBusServerBase(
@@ -72,13 +118,14 @@ def base_server(obj):
 
 
 @pytest.fixture()
-def jeepney_one_time_server(obj):
+def jeepney_one_time_server(obj, signal_obj):
     server = BlockingDBusServer(
         bus='SESSION',
         name='io.github.ffy00.dbus-objects.tests'
     )
 
     server.register_object('/io/github/ffy00/dbus_objects/example', obj)
+    server.register_object('/io/github/ffy00/dbus_objects/example_signal', signal_obj)
 
     # start server
     run = multiprocessing.Event()
